@@ -68,6 +68,13 @@ class DataTypes:
             lang.ES: "{name} debe ser un número hexadecimal válido",
         }
     }
+    numeric = {
+        'regexp': '^[0-9]+$',
+        'message': {
+            lang.EN: "{name} must be a numeric string",
+            lang.ES: "{name} debe ser una cadena numérica",
+        }
+    }
     alfanumeric = {
         'regexp': '^[A-Za-z0-9]+$',
         'message': {
